@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkContourValues extends vtkObject
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -39,6 +39,10 @@ public class vtkContourValues extends vtkObject
   public void GenerateValues(int id0,double id1,double id2)
     { GenerateValues_7(id0,id1,id2); }
 
+  private native void DeepCopy_8(vtkContourValues id0);
+  public void DeepCopy(vtkContourValues id0)
+    { DeepCopy_8(id0); }
+
   public vtkContourValues() { super(); }
 
   public vtkContourValues(long id) { super(id); }
