@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkStructuredGridReader extends vtkDataReader
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -35,9 +35,13 @@ public class vtkStructuredGridReader extends vtkDataReader
   public void SetOutput(vtkStructuredGrid id0)
     { SetOutput_4(id0); }
 
-  private native int ReadMetaData_5(vtkInformation id0);
-  public int ReadMetaData(vtkInformation id0)
-    { return ReadMetaData_5(id0); }
+  private native int ReadMetaDataSimple_5(String id0,vtkInformation id1);
+  public int ReadMetaDataSimple(String id0,vtkInformation id1)
+    { return ReadMetaDataSimple_5(id0,id1); }
+
+  private native int ReadMeshSimple_6(String id0,vtkDataObject id1);
+  public int ReadMeshSimple(String id0,vtkDataObject id1)
+    { return ReadMeshSimple_6(id0,id1); }
 
   public vtkStructuredGridReader() { super(); }
 
